@@ -5,6 +5,7 @@ import json
 import logging
 import uuid
 from collections import defaultdict
+from enum import Enum
 from string import Template
 from typing import Any, Literal
 
@@ -21,6 +22,14 @@ logger = logging.getLogger(__name__)
 _missing_api_key_error_logged: bool = False
 
 
+class AgentType(str, Enum):
+    CLAUDE = "claude"
+    OPENAI = "openai"
+    VLLM = "vllm"
+    LITELLM = "litellm"
+    INTEGRATION_TEST = "integration_test"
+
+
 class Task(BaseModel):
     """
     A task configuration that can be used to create a task.
@@ -325,6 +334,7 @@ class Trace(BaseModel):
 
 __all__ = [
     "AgentResponse",
+    "AgentType",
     "MCPToolCall",
     "MCPToolResult",
     "Trace",
